@@ -35,14 +35,30 @@ test_that("Conversion between edgeList <-> matrix works", {
 
 test_that("Conversion between edgeList <-> graphNEL/igraph/network <-> matrix works", {
     ### Check null graph
-    expect_equivalent(edgeL0, as.edgeList(as(mat0, "graphNEL")))
-    expect_equivalent(edgeL0, as.edgeList(igraph::graph.adjacency(mat0, weighted = TRUE)))
-    expect_equivalent(edgeL0, as.edgeList(network::network(mat0)))
+    if(requireNamespace("graph", quietly = TRUE)){
+        expect_equivalent(edgeL0, as.edgeList(as(mat0, "graphNEL")))
+    }
+
+    if(requireNamespace("igraph", quietly = TRUE)){
+        expect_equivalent(edgeL0, as.edgeList(igraph::graph.adjacency(mat0, weighted = TRUE)))
+    }
+
+    if(requireNamespace("network", quietly = TRUE)){
+        expect_equivalent(edgeL0, as.edgeList(network::network(mat0)))
+    }
     # MISSING TEST FOR BN
 
-    expect_equivalent(edgeL, as.edgeList(as(mat, "graphNEL")))
-    expect_equivalent(edgeL, as.edgeList(igraph::graph.adjacency(mat, weighted = TRUE)))
-    expect_equivalent(edgeL, as.edgeList(network::network(mat)))
+    if(requireNamespace("graph", quietly = TRUE)){
+        expect_equivalent(edgeL, as.edgeList(as(mat, "graphNEL")))
+    }
+
+    if(requireNamespace("igraph", quietly = TRUE)){
+        expect_equivalent(edgeL, as.edgeList(igraph::graph.adjacency(mat, weighted = TRUE)))
+    }
+
+    if(requireNamespace("network", quietly = TRUE)){
+        expect_equivalent(edgeL, as.edgeList(network::network(mat)))
+    }
     # MISSING TEST FOR BN
 })
 
